function [f,A] = fft_generic(t, y)
% [f,A] = fft_generic(t,y)
% Compute a Fast Fourier Transform of time-domain data
%
% Input
%   t - Time samples [s]
%   y - Time-domain signal [a.u.]
%
% Output
%   f - Frequency [Hz]
%   A - Amplitude of Fourier transform [a.u., same as input signal]
%
% (c) Alex Valavanis
%     University of Leeds, 2017

  n = length(t); % Number of samples in the raw signal

  % Now perform the FFT to get the spectrum
  amp = fft(y);

  % Single sided amplitude is obtained here
  A = abs(amp/n);

  dt = t(2) - t(1);
  fs = 1/dt; % Sampling frequency [Hz]

  % Compute the frequency scale [Hz]
  f = (0:n-1) * fs/n;
end
