function [freq,amp] = fftsmspec_interpolated(fullfilepath)
% [freq,amp] = fftsmspec_interpolated(fullfilepath)
% This function computes the FFT spectrum from folded-path self-mixing data.
%
% Input
%   fullfilepath - full path to a file containing data in 2 columns:
%     column 1: the displacement of the translation stage in mm
%     column 2: the signal [a.u.]
%
% Output
%   freq - frequency [THz]
%   amp  - amplitude [in the same units as the signal]
%
% (c) University of Leeds, 2017

  spatial_domain_data = importdata(fullfilepath);

  x = spatial_domain_data(:,1); % Position [mm]
  s = spatial_domain_data(:,2); % Self-mixing amplitude [V]

  %% Data sorting.  If this is a reverse scan, flip the sign on the positions 
  if x(1) > x(end)
      x = -x;
  end

  % Find the total round-trip delay time corresponding to each spatial sample
  % Note that the position is multiplied by 4, as the beam is folded, and
  % fed back.
  c = physconst('LightSpeed') * 1000; % [mm/s]
  t = x * 4.0 / c; % [s]

  [freq, amp] = fft_generic(t, s);
  freq = freq / 1e12; % Rescale to THz
end
